@@ -1,14 +1,6 @@
 [
   {
     'tests' => {
-      'sender-id-pick-spf' => {
-        'spec' => '',
-        'mailfrom' => 'user@example5.net',
-        'description' => 'SenderID with mfrom and SPF, pick SPF',
-        'result' => 'pass',
-        'host' => '1.2.3.5',
-        'helo' => 'mail.example.net'
-      },
       'sender-id-pick-mfrom1' => {
         'spec' => '',
         'mailfrom' => 'user@example3.net',
@@ -17,15 +9,6 @@
         'host' => '1.2.3.5',
         'helo' => 'mail.example.net'
       },
-      'spf-by-cname' => {
-        'spec' => '',
-        'comment' => 'The SPF Lookup returns a CNAME and the SPF record',
-        'mailfrom' => 'user@example.net',
-        'description' => 'TXT/SPF records can be referenced through CNAME',
-        'result' => 'pass',
-        'host' => '1.2.3.5',
-        'helo' => 'mail.example.net'
-      },
       'sender-id-pick-mfrom2' => {
         'spec' => '',
         'mailfrom' => 'user@example4.net',
@@ -34,15 +17,6 @@
         'host' => '1.2.3.5',
         'helo' => 'mail.example.net'
       },
-      'p-in-exp-mod' => {
-        'spec' => '',
-        'explanation' => 'forbidden for one.two.three.five.example.net',
-        'mailfrom' => 'user@example1.net',
-        'description' => '%{p} in exp= modifier',
-        'result' => 'fail',
-        'host' => '1.2.3.5',
-        'helo' => 'mail.example.net'
-      },
       'domain-dots-at-end' => {
         'spec' => '4.3/1',
         'mailfrom' => 'user@example5.net....',
@@ -58,6 +32,40 @@
         'result' => 'pass',
         'host' => '1.2.3.5',
         'helo' => 'mail.example.net'
+      },
+      'sender-id-pick-spf' => {
+        'spec' => '',
+        'mailfrom' => 'user@example5.net',
+        'description' => 'SenderID with mfrom and SPF, pick SPF',
+        'result' => 'pass',
+        'host' => '1.2.3.5',
+        'helo' => 'mail.example.net'
+      },
+      'ptr-cname' => {
+        'spec' => '',
+        'mailfrom' => 'user@example6.net',
+        'description' => 'PTR record is CNAME to PTR record',
+        'result' => 'pass',
+        'host' => '2.3.4.5',
+        'helo' => 'mail.example.net'
+      },
+      'spf-by-cname' => {
+        'spec' => '',
+        'comment' => 'The SPF Lookup returns a CNAME and the SPF record',
+        'mailfrom' => 'user@example.net',
+        'description' => 'TXT/SPF records can be referenced through CNAME',
+        'result' => 'pass',
+        'host' => '1.2.3.5',
+        'helo' => 'mail.example.net'
+      },
+      'p-in-exp-mod' => {
+        'spec' => '',
+        'explanation' => 'forbidden for one.two.three.five.example.net',
+        'mailfrom' => 'user@example1.net',
+        'description' => '%{p} in exp= modifier',
+        'result' => 'fail',
+        'host' => '1.2.3.5',
+        'helo' => 'mail.example.net'
       }
     },
     'description' => 'various other tests',
@@ -88,6 +96,11 @@
           'SPF' => 'spf2.0/mfrom ip4:1.2.3.5 -all'
         }
       ],
+      'friend.example6.net' => [
+        {
+          'A' => '2.3.4.5'
+        }
+      ],
       'example2.net' => [
         {
           'SPF' => 'spf2.0/pra,mfrom ip4:1.2.3.5 -all'
@@ -103,6 +116,16 @@
           'SPF' => 'v=spf1 -ip4:1.2.3.5 all exp=%{p4r}.explain.example1.net'
         }
       ],
+      'example6.net' => [
+        {
+          'SPF' => 'v=spf1 ptr:friend.example6.net -all'
+        }
+      ],
+      'two.three.four.five.example.net' => [
+        {
+          'PTR' => 'friend.example6.net'
+        }
+      ],
       'example4.net' => [
         {
           'SPF' => 'spf2.0/mfrom -ip4:1.2.3.5 all'
@@ -116,6 +139,11 @@
           'SPF' => 'v=spf1 ip4:1.2.3.5 -all'
         }
       ],
+      '5.4.3.2.in-addr.arpa' => [
+        {
+          'CNAME' => 'two.three.four.five.example.net'
+        }
+      ],
       'one.two.three.five.example.net' => [
         {
           'A' => '1.2.3.5'
